@@ -9,7 +9,7 @@ use vars qw($VERSION @ISA @EXPORT_OK);
 use XML::DT;
 use XML::TMX::Writer;
 
-$VERSION = '0.29';
+$VERSION = '0.30';
 @ISA = 'Exporter';
 @EXPORT_OK = qw();
 
@@ -269,6 +269,7 @@ sub _compute_header {
 sub for_tu {
     my $self = shift;
     my $conf = { -header => 1 };
+    my $i = 0;
 
     ref($_[0]) eq "HASH" and $conf = {%$conf , %{shift(@_)}};
 
@@ -312,6 +313,7 @@ sub for_tu {
                      %v = %$v if ($v && ref($v) eq "HASH");
 
                      my %ans = (%v, %$ans);
+                     $ans{"-n"}=$i if $conf->{n} ;
                      $tmx->add_tu(-verbatim => $conf->{-verbatim}, %ans);
                  }
              },
@@ -378,7 +380,6 @@ sub for_tu {
     }
 
     $/ = "</tu>";
-    my $i = 0;
     $conf->{-verbose}++ if $conf->{verbose};
     print STDERR "." if $conf->{-verbose};
     while (<X>) {
@@ -398,6 +399,7 @@ sub for_tu {
         if ($conf->{'-raw'}) {
             my $ans = $code->($_);
             if ($conf->{-output}) {
+                $ans->{"-n"}=$i if $conf->{n} ;
                 $tmx->add_tu(-raw => $ans);
             }
         } else {
