@@ -6,7 +6,7 @@ use strict;
 use Exporter ();
 use vars qw($VERSION @ISA @EXPORT_OK);
 
-$VERSION = '0.29';
+$VERSION = '0.30';
 @ISA = 'Exporter';
 @EXPORT_OK = qw();
 
@@ -412,6 +412,10 @@ sub add_tu {
         @note = @{$tuv{"-note"}};
         delete $tuv{"-note"};
     }
+    if (defined($tuv{"-n"})) {
+        $opt{id}=$tuv{"-n"};
+        delete $tuv{"-n"};
+    }
 
     $self->_startTag(0,'tu', %opt)->_nl;
 
